diff --git a/pytato/array.py b/pytato/array.py
index 9366dc8ffbb569ef40bf52f40ecd0cb859c524bc..0f9fc5db1d31ebc4d46dd3ba29597dd6fd154de0 100644
--- a/pytato/array.py
+++ b/pytato/array.py
@@ -267,7 +267,7 @@ def normalize_shape(
 # }}}
 
 
-# {{{ array inteface
+# {{{ array interface
 
 ConvertibleToIndexExpr = Union[int, slice, "Array", None, EllipsisType]
 IndexExpr = Union[IntegralT, "NormalizedSlice", "Array", None, EllipsisType]
@@ -376,7 +376,7 @@ class Array(Taggable):
             :class:`~pytato.array.IndexLambda` is used to produce
             references to named arrays. Since any array that needs to be
             referenced in this way needs to obey this restriction anyway,
-            a decision was made to requir the same of *all* array expressions.
+            a decision was made to require the same of *all* array expressions.
 
     .. attribute:: dtype
 
@@ -1803,7 +1803,7 @@ def roll(a: Array, shift: int, axis: Optional[int] = None) -> Array:
     if axis is None:
         if a.ndim > 1:
             raise NotImplementedError(
-                    "shifing along more than one dimension is unsupported")
+                    "shifting along more than one dimension is unsupported")
         else:
             axis = 0
 
diff --git a/pytato/transform/__init__.py b/pytato/transform/__init__.py
index e759a7e82033fafc35fae74ebb24d340bb7e239f..69cfd1e738fdfb55a61dd913e5c65e81625e18a8 100644
--- a/pytato/transform/__init__.py
+++ b/pytato/transform/__init__.py
@@ -1263,8 +1263,8 @@ def _materialize_if_mpms(expr: Array,
                          ) -> MPMSMaterializerAccumulator:
     """
     Returns an instance of :class:`MPMSMaterializerAccumulator`, that
-    materializes *expr* if it has more than 1 successors and more than 1
-    materialized predecessors.
+    materializes *expr* if it has more than 1 successor and more than 1
+    materialized predecessor.
     """
     from functools import reduce
 
@@ -1539,8 +1539,8 @@ def materialize_with_mpms(expr: DictOfNamedArrays) -> DictOfNamedArrays:
     .. note::
 
         - MPMS materialization strategy is a greedy materialization algorithm in
-          which any node with more than 1 materialized predecessors and more than
-          1 successors is materialized.
+          which any node with more than 1 materialized predecessor and more than
+          1 successor is materialized.
         - Materializing here corresponds to tagging a node with
           :class:`~pytato.tags.ImplStored`.
         - Does not attempt to materialize sub-expressions in